##  General Formatting Rules
Rule |  Details
---|---
Character encoding | Supports [UTF-8 character encoding![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fen.wikipedia.org%2Fwiki%2FUTF-8 "https://en.wikipedia.org/wiki/UTF-8") for string fields. However, values themselves cannot contain “<" (less than) or ";" (semicolon). A semicolon is used to separate values in a cell.
Date format | Enter dates as: yyyy-mm-dd
Number format | Use points (“.”) for decimals (e.g., 1.7 = one point seven) Use commas (“,”) for thousands (e.g., 1,700 = one thousand seven hundred)
Case sensitivity | Values are case-sensitive, so ensure the correct case.


